@@ -11,10 +11,10 @@ import volmdlr.primitives3D as p3D
 
 sphere=p3D.Sphere(vm.Point3D((0,0,0)),4)
 
-cylinder=p3D.Cylinder((0,0,0),(0,0,1),0.5,10)
+cylinder=p3D.Cylinder(vm.Point3D((0,0,0)), vm.Vector3D((0,0,1)), 0.5, 10)
 
-cut=p3D.Cut(sphere,cylinder)
+cut=p3D.Cut(sphere,cylinder, name='cutted sphere')
 
-model=vm.VolumeModel([cut])
+model=vm.VolumeModel([('cut', [cut])])
 
-model.FreeCADExport('python','cut','/usr/lib/freecad/lib')
\ No newline at end of file
+model.FreeCADExport('cut')
\ No newline at end of file
